#!/bin/bash


####################################### 初始化系统环境 #######################################

apt-get update
apt-get install -y gcc g++ make wget libpcre3 libpcre3-dev libssl-dev libxml2 libxml2-dev

####################################### 下载源码包 #######################################

wget -c http://nginx.org/download/nginx-1.10.1.tar.gz
wget -c http://cn2.php.net/distributions/php-7.0.8.tar.gz

####################################### 开始安装Nginx #######################################

# 新建www用户
useradd -s /sbin/nologin www

# 解压并安装
tar zxvf nginx-1.10.1.tar.gz
cd nginx-1.10.1
sed -i 's:CFLAGS="$CFLAGS -g":# CFLAGS="$CFLAGS -g":g' auto/cc/gcc
./configure --user=www --group=www --prefix=/usr/local/nginx
make && make install
cd ..

# 配置文件
cp /usr/local/nginx/conf/nginx.conf /usr/local/nginx/conf/nginx.conf.default

echo '
user  www;
worker_processes  1;

error_log  logs/error.log;

events {
    worker_connections  1024;
}

http {

    include       mime.types;
    default_type  application/octet-stream;

    log_format  main  "$remote_addr - $remote_user [$time_local] $request $status $body_bytes_sent";

    access_log  logs/access.log  main;

    sendfile        on;
    keepalive_timeout  65;

    server {

        listen       80;
        server_name  localhost;
        root         /www/html/;

        location / {
            index  index.html index.htm index.php;
        }

        location ~ \.php$ {
            fastcgi_pass   127.0.0.1:9000;
            fastcgi_index  index.php;
            fastcgi_param  SCRIPT_FILENAME  $document_root$fastcgi_script_name;
            include        fastcgi_params;
        }

    }

}
' > /usr/local/nginx/conf/nginx.conf

mkdir /www/html -p
echo '<?php phpinfo();' > /www/html/index.php

# 快捷方式
ln -s /usr/local/nginx/sbin/nginx /usr/bin/nginx
ln -s /usr/local/nginx/conf/nginx.conf /etc/nginx.conf

# 启动 Nginx
nginx

####################################### 开始安装 PHP #######################################

tar zxvf php-7.0.8.tar.gz
cd php-7.0.8
./configure --prefix=/usr/local/php --enable-fpm
make && make install

# 添加PHP常用命令
ln -s /usr/local/php/bin/php /usr/bin/php
ln -s /usr/local/php/bin/phpize /usr/bin/phpize
ln -s /usr/local/php/bin/php-config /usr/bin/php-config
ln -s /usr/local/php/sbin/php-fpm /usr/bin/php-fpm

# 配置文件
cp php.ini-production /usr/local/php/lib/php.ini
cp /usr/local/php/etc/php-fpm.conf.default /usr/local/php/etc/php-fpm.conf
cp /usr/local/php/etc/php-fpm.d/www.conf.default /usr/local/php/etc/php-fpm.d/www.conf
cd ..

# 修改PHP配置文件
sed -i 's/post_max_size = 8M/post_max_size = 50M/g' /usr/local/php/lib/php.ini
sed -i 's/upload_max_filesize = 2M/upload_max_filesize = 50M/g' /usr/local/php/lib/php.ini
sed -i 's/;date.timezone =/date.timezone = PRC/g' /usr/local/php/lib/php.ini
sed -i 's/expose_php = On/expose_php = Off/g' /usr/local/php/lib/php.ini
sed -i 's/user = nobody/user = www/g' /usr/local/php/etc/php-fpm.d/www.conf
sed -i 's/group = nobody/group = www/g' /usr/local/php/etc/php-fpm.d/www.conf

# 创建PHP配置文件快捷方式
ln -s /usr/local/php/lib/php.ini /etc/php.ini

# 启动 php-fpm
php-fpm
